@@ -1,7 +1,7 @@
 /* -*-pgsql-c-*- */
 /*
  *
- * $Header: /home/prj/pg/ipa-pgpool2/cvsroot/ipa-pgpool2/pgpool_src/pool.h,v 1.56 2006/08/16 13:51:10 t-ishii Exp $
+ * $Header: /cvsroot/pgpool/pgpool-II/pool.h,v 1.2 2006/09/14 02:04:08 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -271,9 +271,14 @@ typedef struct {
 	UNIT unit;
 } Interval;
 
+#ifdef NOT_USED
 #define NUM_BACKENDS (in_load_balance? (selected_slot+1) : \
 					  (((!REPLICATION && !PARALLEL_MODE)||master_slave_dml)? Req_info->master_node_id+1: \
 					   pool_config->backend_desc->num_backends))
+#endif
+#define NUM_BACKENDS (in_load_balance? (selected_slot+1) : \
+					  (((!REPLICATION && !PARALLEL_MODE) && !MASTER_SLAVE)? Req_info->master_node_id+1: \
+					   pool_config->backend_desc->num_backends))
 #define BACKEND_INFO(backend_id) (pool_config->backend_desc->backend_info[(backend_id)])
 #define LOAD_BALANCE_STATUS(backend_id) (pool_config->load_balance_status[(backend_id)])
 #define VALID_BACKEND(backend_id) \
