@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/prj/pg/ipa-pgpool2/cvsroot/ipa-pgpool2/pgpool_src/pool_process_query.c,v 1.79 2006/08/16 07:00:36 y-asaba Exp $
+ * $Header: /cvsroot/pgpool/pgpool-II/pool_process_query.c,v 1.3 2006/09/14 02:00:45 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -893,7 +893,7 @@ static POOL_STATUS SimpleQuery(POOL_CONNECTION *frontend,
 			start_load_balance(backend);
 		else if (MASTER_SLAVE)
 		{
-			pool_debug("SimpleQuery: set master_slave_dml query: %s", query);
+			pool_debug("SimpleQuery: set master_slave_dml query: %s", string);
 			master_slave_was_enabled = 1;
 			MASTER_SLAVE = 0;
 			master_slave_dml = 1;
@@ -1941,6 +1941,12 @@ static POOL_STATUS CopyDataRows(POOL_CONNECTION *frontend,
 			{
 				if (pool_flush(CONNECTION(backend, i)) <0)
 					return POOL_END;
+
+				if (pool_config->replication_strict)
+				{
+					if (synchronize(CONNECTION(backend, i)))
+						return POOL_END;
+				}
 			}
 		}
 	}
